<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-it',
'0_langue' => 'Italiana [it_fem]',
'0_liste' => 'spip-it@rezo.net',
'0_mainteneur' => 'fausto@nosmet.com',

// A
'access_interface_graphique' => 'Ritorna all\'interfaccia grafica completa',
'access_mode_texte' => 'Visualizza l\'interfaccia testuale semplificata',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Modifica l\'articolo',
'admin_modifier_auteur' => 'Modifica l\'autrice',
'admin_modifier_breve' => 'Modifica la breve',
'admin_modifier_mot' => 'Modifica la parola chiave',
'admin_modifier_rubrique' => 'Modifica la rubrica',
'admin_recalculer' => 'Rigenera la pagina',
'afficher_trad' => 'visualizzare le traduzioni',
'alerte_maj_impossible' => '<b>Attenzione!</b> L\'aggiornamento del database SQL alla versione @version@ &egrave; impossibile, forse non si possiedono i diritti di modifica nel database. Contattare il proprio fornitore di hosting.',
'alerte_modif_info_concourante' => 'ATTENZIONE: Questa informazione &egrave; stata modificata altrove. Il valore attuale &egrave;:',
'analyse_xml' => 'Analisi XML',
'annuler' => 'Annulla',
'antispam_champ_vide' => 'Si prega di lasciare vuoto questo campo:',
'articles_recents' => 'Articoli pi&ugrave; recenti',
'avis_archive_incorrect' => 'il file archivio non &egrave; un file SPIP',
'avis_archive_invalide' => 'il file archivio non &egrave; valido',
'avis_attention' => 'ATTENZIONE!',
'avis_champ_incorrect_type_objet' => 'Nome di campo errato @name@ per oggetto di tipo ',
'avis_colonne_inexistante' => 'La colonna @col@ non esiste',
'avis_echec_syndication_01' => 'La syndication &egrave; fallita: il backend indicato &egrave; indecifrabile o non propone alcun articolo.',
'avis_echec_syndication_02' => 'La syndication &egrave; fallita: impossibile accedere al backend di questo sito.',
'avis_erreur' => 'Errore: vedi sopra',
'avis_erreur_connexion' => 'Errore di connessione',
'avis_erreur_cookie' => 'problema di cookie',
'avis_erreur_fonction_contexte' => 'Errore di programmazione. Questa funzione non deve essere chiamata in questo contesto.',
'avis_erreur_mysql' => 'Errore SQL ',
'avis_erreur_sauvegarde' => 'Errore nel salvataggio (@type@ @id_objet@)! ',
'avis_erreur_visiteur' => 'Problema di accesso all\'area riservata',

// B
'barre_a_accent_grave' => 'Inserire una A maiscola con accento grave',
'barre_aide' => 'Utilizzare le scorciatoie tipografiche di SPIP per migliorare l\'impaginazione del testo',
'barre_e_accent_aigu' => 'Inserire una E maiscola con accento acuto',
'barre_eo' => 'Inserire una E nell\'O',
'barre_eo_maj' => 'Inserire una E nell\'O maiuscola',
'barre_euro' => 'Inserire il simbolo &euro;',
'barre_gras' => 'Formattare in {{grassetto}}',
'barre_guillemets' => 'Porre il testo fra &laquo; virgolette basse francesi &raquo;',
'barre_guillemets_simples' => 'Porre il testo fra &#132;virgolette&#147;',
'barre_intertitre' => 'Trasformare in {{{titolo di paragrafo}}}',
'barre_italic' => 'Formattare in {corsivo}',
'barre_lien' => 'Trasformare in un [link ipertestuale->http://...]',
'barre_lien_input' => 'Indicare l\'indirizzo del link (&egrave; possibile indicare l\'indirizzo Web come http://www.ilmiosito.com o semplicemente indicare il numero di un singolo articolo).',
'barre_note' => 'Trasformare in [[Nota a fondo pagina]]',
'barre_paragraphe' => 'Crea un paragrafo',
'barre_quote' => '<quote>Citare un messaggio</quote>',
'bouton_ajouter_document' => 'Aggiungi un documento',
'bouton_ajouter_image' => 'Aggiungi un\'immagine',
'bouton_ajouter_image_document' => 'Aggiungi un\'immagine o&nbsp;un&nbsp;documento',
'bouton_changer' => 'Cambia',
'bouton_chercher' => 'Cerca',
'bouton_choisir' => 'Scegli',
'bouton_download' => 'Download',
'bouton_enregistrer' => 'Salva',
'bouton_radio_desactiver_messagerie_interne' => 'Disattiva la messaggistica interna',
'bouton_radio_envoi_annonces' => 'Invia gli annunci editoriali',
'bouton_radio_non_envoi_annonces' => 'Non inviare annunci',
'bouton_radio_non_envoi_liste_nouveautes' => 'Non inviare l\'elenco delle novit&agrave;',
'bouton_recharger_page' => 'ricaricare questa pagina',
'bouton_telecharger' => 'Upload',
'bouton_valider' => 'Invia',

// C
'cal_apresmidi' => 'pomeriggio',
'cal_jour_entier' => 'giorno intero',
'cal_matin' => 'mattina',
'cal_par_jour' => 'calendario giornaliero',
'cal_par_mois' => 'calendario mensile',
'cal_par_semaine' => 'calendario settimanale',
'choix_couleur_interface' => 'colore',
'choix_interface' => 'scelta dell\'interfaccia',
'colonne' => 'Colonna',
'confirm_changer_statut' => 'Attenzione, &egrave; stato chiesto di modificare lo status di questo elemento. Continuare?',
'correcte' => 'corretto',

// D
'date_aujourdhui' => 'oggi',
'date_avant_jc' => 'a.C.',
'date_dans' => 'tra @delai@',
'date_de_mois_1' => '@j@ gennaio',
'date_de_mois_10' => '@j@ ottobre',
'date_de_mois_11' => '@j@ novembre',
'date_de_mois_12' => '@j@ dicembre',
'date_de_mois_2' => '@j@ febbraio',
'date_de_mois_3' => '@j@ marzo',
'date_de_mois_4' => '@j@ aprile',
'date_de_mois_5' => '@j@ maggio',
'date_de_mois_6' => '@j@ giugno',
'date_de_mois_7' => '@j@ luglio',
'date_de_mois_8' => '@j@ agosto',
'date_de_mois_9' => '@j@ settembre',
'date_demain' => 'domani',
'date_fmt_heures_minutes' => '@h@:@m@',
'date_fmt_jour_heure' => '@jour@ ore @heure@',
'date_fmt_jour_mois' => '@jourmois@',
'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => 'il @nomjour@ @date@',
'date_heures' => 'ore',
'date_hier' => 'ieri',
'date_il_y_a' => '@delai@ fa',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'domenica',
'date_jour_1_abbr' => 'dom',
'date_jour_1_initiale' => 'd',
'date_jour_2' => 'luned&igrave;',
'date_jour_2_abbr' => 'lun',
'date_jour_2_initiale' => 'l',
'date_jour_3' => 'marted&igrave;',
'date_jour_3_abbr' => 'mar',
'date_jour_3_initiale' => 'm',
'date_jour_4' => 'mercoled&igrave;',
'date_jour_4_abbr' => 'mer',
'date_jour_4_initiale' => 'm',
'date_jour_5' => 'gioved&igrave;',
'date_jour_5_abbr' => 'giov',
'date_jour_5_initiale' => 'g',
'date_jour_6' => 'venerd&igrave;',
'date_jour_6_abbr' => 'ven',
'date_jour_6_initiale' => 'v',
'date_jour_7' => 'sabato',
'date_jour_7_abbr' => 'sab',
'date_jour_7_initiale' => 's',
'date_jours' => 'giorni',
'date_minutes' => 'minuti',
'date_mois' => 'mesi',
'date_mois_1' => 'Gennaio',
'date_mois_10' => 'Ottobre',
'date_mois_11' => 'Novembre',
'date_mois_12' => 'Dicembre',
'date_mois_2' => 'Febbraio',
'date_mois_3' => 'Marzo',
'date_mois_4' => 'Aprile',
'date_mois_5' => 'Maggio',
'date_mois_6' => 'Giugno',
'date_mois_7' => 'Luglio',
'date_mois_8' => 'Agosto',
'date_mois_9' => 'Settembre',
'date_saison_1' => 'inverno',
'date_saison_2' => 'primavera',
'date_saison_3' => 'estate',
'date_saison_4' => 'autunno',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'settimane',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => ' per iniziare realmente l\'installazione',
'dirs_preliminaire' => 'Prima di iniziare: <b>impostare i diritti di accesso</b>',
'dirs_probleme_droits' => 'Problema nei diritti di accesso',
'dirs_repertoires_absents' => '<p><b>Le seguenti cartelle non sono state trovate: </b></p><ul>@bad_dirs@.</ul>
  <p>Probabilmente ci&ograve; &egrave; dovuto a un\'errata formattazione delle lettere maiuscole o minuscole.
  Verificare che le maiuscole e le minuscole delle cartelle coincidano con quelle visualizzate
  qui sopra; se non &egrave; cos&igrave;, rinominare le cartelle utilizzando il software FTP.
  <p>Una volta effettuata questa correzione, si potr&agrave;',
'dirs_repertoires_suivants' => '<p><b>Le seguenti cartelle non sono accessibili in scrittura:</b></p> <ul>@bad_dirs@</ul>
<p>Per risolvere il problema, utilizzare un client FTP per impostare i diritti di accesso
di ciascuna di queste cartelle. La procedura &egrave; spiegata in dettaglio nella guida d\'installazione.</p>
<p>Una volta attribuiti i permessi, si potr&agrave; ',
'double_occurrence' => 'Doppia occorrenza', # MODIF

// E
'en_cours' => 'in corso',
'entree_dimensions' => 'Dimensioni:',
'entree_titre_document' => 'Titolo del documento:',
'entree_titre_image' => 'Titolo dell\'immagine:',
'envoi_via_le_site' => 'Invio tramite il sito',
'erreur' => 'Errore',
'erreur_balise_non_fermee' => 'ultimo tag non chiuso:',
'erreur_texte' => 'errore/i',
'etape' => 'Fase',

// F
'fichier_introuvable' => 'File @fichier@ non trovato',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Sei gi&agrave; iscritta.',
'form_email_non_valide' => 'L\'indirizzo email non &egrave; valido.',
'form_forum_access_refuse' => 'Non hai pi&ugrave; accesso a questo sito.',
'form_forum_bonjour' => 'Buongiorno @nom@,',
'form_forum_email_deja_enregistre' => 'Questo indirizzo email &egrave; gi&agrave; registrato, puoi dunque utilizzare la tua password abituale.',
'form_forum_identifiant_mail' => 'Il nuovo codice identificativo (ID) ti &egrave; stato appena inviato tramite email.',
'form_forum_identifiants' => 'Dati personali',
'form_forum_indiquer_nom_email' => 'Indica qui nome e indirizzo email.  L\'ID personale ti verr&agrave; recapitato tramite email a breve.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(questo &egrave; un messaggio generato automaticamente)',
'form_forum_pass' => 'password:',
'form_forum_probleme_mail' => 'Problema di posta: l\'ID non pu&ograve; essere inviato.',
'form_forum_voici1' => 'Ecco i dati per poter partecipare ai forum
 del sito"@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Ecco i dati per poter proporre degli articoli sul sito
"@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Indica il tuo indirizzo email.',
'form_indiquer_nom' => 'Indica il tuo nome.',
'form_indiquer_nom_site' => 'Indica il nome del tuo sito.',
'form_pet_adresse_site' => 'Indirizzo del sito',
'form_pet_aucune_signature' => 'Nessuna adesione corrisponde a questo codice...',
'form_pet_confirmation' => 'Conferma l\'adesione:',
'form_pet_deja_enregistre' => 'Questo sito &egrave; gi&agrave; registrato',
'form_pet_deja_signe' => 'Hai gi&agrave; firmato questo testo.',
'form_pet_envoi_mail_confirmation' => 'Ti &egrave; stato appena inviato un messaggio di posta elettronica. Dovrai visitare l\'indirizzo web che appare nel messaggio per confermare la tua adesione.',
'form_pet_mail_confirmation' => 'Salve,

Hai richiesto di firmare la petizione:
@titre@.

Hai fornito le seguenti informazioni:
    Nome: @nom_email@
    Sito: @nom_site@ - @url_site@
    @message@

IMPORTANTE...

Per confermare la tua adesione &egrave; sufficiente visitare l\'indirizzo web qui sotto (se non lo fai, la tua domanda sar&agrave; respinta):

    @url@


Grazie per la partecipazione',
'form_pet_message_commentaire' => 'Un messaggio, un commento?',
'form_pet_nom_site2' => 'Nome del tuo sito Web',
'form_pet_probleme_liens' => 'Per favore, riprenda il suo messaggio ed elimini i link ipertestuali.',
'form_pet_probleme_technique' => 'Le adesioni sono temporaneamente sospese per il verificarsi di problemi tecnici.',
'form_pet_signature_pasprise' => 'La tua adesione non &egrave; stata presa in considerazione.',
'form_pet_signature_validee' => 'La tua adesione &egrave; stata confermata. Grazie!',
'form_pet_site_deja_enregistre' => 'Questo sito &egrave; gi&agrave; registrato',
'form_pet_url_invalide' => 'L\'URL indicato non risulta valido.',
'form_pet_votre_email' => 'Il tuo indirizzo email',
'form_pet_votre_nom' => 'Nome o pseudonimo',
'form_pet_votre_site' => 'Se hai un sito Web, puoi segnalarlo qui sotto',
'form_prop_confirmer_envoi' => 'Conferma l\'invio',
'form_prop_description' => 'Descrizione/commento',
'form_prop_enregistre' => 'La tua proposta &egrave; stata registrata ed apparir&agrave; on line dopo l\'approvazione della responsabile del sito.',
'form_prop_envoyer' => 'Invia un messaggio',
'form_prop_indiquer_email' => 'Indica un indirizzo email valido',
'form_prop_indiquer_nom_site' => 'Indica il nome del sito.',
'form_prop_indiquer_sujet' => 'Indica un argomento',
'form_prop_message_envoye' => 'Messaggio inviato',
'form_prop_nom_site' => 'Nome del sito',
'form_prop_non_enregistre' => 'La tua proposta non &egrave; stata registrata.',
'form_prop_sujet' => 'Argomento',
'form_prop_url_site' => 'Indirizzo (URL) del sito',
'forum_acces_refuse' => 'Non hai accesso a questi forum.',
'forum_attention_dix_caracteres' => '<b>Attenzione!</b> il messaggio deve contenere almeno dieci caratteri.',
'forum_attention_trois_caracteres' => '<b>Attenzione!</b> il titolo deve contenere almeno tre caratteri.',
'forum_attention_trop_caracteres' => '<b>Attenzione!</b> il messaggio &egrave; troppo lungo (@compte@ caratteri): per poter essere registrato esso non deve essere pi&ugrave; lungo di @max@ caratteri.',
'forum_avez_selectionne' => 'Hai selezionato:',
'forum_cliquer_retour' => 'Clicca <a href=\'@retour_forum@\'>qui</a> per continuare.',
'forum_forum' => 'forum',
'forum_info_modere' => 'Questo forum &egrave; moderato a priori: il tuo contributo apparir&agrave; solo dopo essere stato approvato da un\'amministratrice del sito.',
'forum_lien_hyper' => '<b>Link ipertestuale</b> (opzionale)',
'forum_message_definitif' => 'Messaggio definitivo: invialo al sito',
'forum_message_trop_long' => 'Il tuo messaggio &egrave; troppo lungo. La dimensione massima &egrave; di 20000 caratteri.',
'forum_ne_repondez_pas' => 'Non rispondere a questo email ma intervieni sul forum all\'indirizzo seguente:',
'forum_non_inscrit' => 'Non sei iscritta, oppure l\'indirizzo o la password inseriti non sono corretti.',
'forum_page_url' => '(Se il tuo messaggio si riferisce ad un articolo pubblicato sul Web o ad una pagina contenente maggiori informazioni, &egrave; possibile indicare di seguito il titolo della pagina ed il suo indirizzo URL.)',
'forum_par_auteur' => 'di @auteur@',
'forum_poste_par' => 'Messaggio inviato da @parauteur@ in calce all\'articolo  &laquo; @titre@ &raquo;.',
'forum_probleme_database' => 'Problema nel database. Il tuo messaggio non &egrave; stato registrato.',
'forum_qui_etes_vous' => '<b>Chi sei?</b> (opzionale)',
'forum_texte' => 'Testo del messaggio:',
'forum_titre' => 'Titolo:',
'forum_titre_erreur' => 'Errore...',
'forum_url' => 'URL:',
'forum_valider' => 'Conferma la scelta',
'forum_voir_avant' => 'Vedi il messaggio prima di inviarlo',
'forum_votre_email' => 'Indirizzo email:',
'forum_votre_nom' => 'Nome (o pseudonimo):',
'forum_vous_enregistrer' => '&Egrave; necessario iscriversi
per partecipare a questo forum.  Indica qui sotto l\'ID personale
che ti &egrave; stato fornito.  Se non sei registrata, devi',
'forum_vous_inscrire' => 'prima iscriverti.',

// I
'ical_texte_rss_articles' => 'Il file di "backend" degli articoli di questo sito si trova al seguente indirizzo:',
'ical_texte_rss_articles2' => '&Egrave; anche possibile ottenere un file di "backend" per gli articoli di una singola rubrica:',
'ical_texte_rss_breves' => 'Inoltre esiste un file per l\'insieme delle brevi del sito. Precisando un numero di rubrica ci si pu&ograve; limitare alle brevi in essa contenute.',
'icone_a_suivre' => 'Pannello di controllo',
'icone_admin_site' => 'Amministrazione del sito',
'icone_agenda' => 'Agenda',
'icone_aide_ligne' => 'Guida in linea',
'icone_articles' => 'Articoli',
'icone_auteurs' => 'Autrici',
'icone_breves' => 'Brevi',
'icone_brouteur' => 'Navigazione rapida',
'icone_configuration_site' => 'Configurazione del sito',
'icone_configurer_site' => 'Configura il sito',
'icone_creer_nouvel_auteur' => 'Crea una nuova autrice',
'icone_creer_rubrique' => 'Crea una rubrica',
'icone_creer_sous_rubrique' => 'Crea una sottorubrica',
'icone_deconnecter' => 'Esci',
'icone_discussions' => 'Discussioni',
'icone_doc_rubrique' => 'Documenti delle rubriche',
'icone_ecrire_article' => 'Scrivi un articolo',
'icone_edition_site' => 'Redazione del sito',
'icone_forum_administrateur' => 'Forum delle amministratrici',
'icone_forum_suivi' => 'Monitoraggio dei forum',
'icone_gestion_langues' => 'Gestione delle lingue',
'icone_informations_personnelles' => 'Dati personali',
'icone_interface_complet' => 'Interfaccia completa',
'icone_interface_simple' => 'Interfaccia semplificata',
'icone_maintenance_site' => 'Manutenzione tecnica',
'icone_messagerie_personnelle' => 'Messaggi personali',
'icone_mots_cles' => 'Parole chiave',
'icone_nouvelle_breve' => 'Scrivi una breve',
'icone_repartition_actuelle' => 'Mostra la ripartizione attuale',
'icone_repartition_debut' => 'Mostra la ripartizione dall\'inizio',
'icone_repartition_visites' => 'Distribuzione delle visite',
'icone_rubriques' => 'Rubriche',
'icone_sauver_site' => 'Backup del sito',
'icone_site_entier' => 'Tutto il sito',
'icone_sites_references' => 'Siti repertoriati',
'icone_statistiques' => 'Statistiche del sito',
'icone_statistiques_visites' => 'Statistiche delle visite',
'icone_suivi_activite' => 'Monitorare l\'attivit&agrave; del sito',
'icone_suivi_actualite' => 'Evoluzione del&nbsp;sito',
'icone_suivi_forums' => 'Gestione dei forum',
'icone_suivi_pettions' => 'Gestione delle petizioni',
'icone_suivi_revisions' => 'Modifiche agli articoli',
'icone_supprimer_document' => 'Elimina il documento',
'icone_supprimer_image' => 'Elimina l\'immagine',
'icone_supprimer_message' => 'Elimina il messaggio',
'icone_tous_articles' => 'Tutti i tuoi articoli',
'icone_tous_auteur' => 'Tutte le autrici',
'icone_valider_message' => 'Convalida il messaggio',
'icone_visiter_site' => 'Visita il sito',
'icone_voir_en_ligne' => 'Vedi on line',
'image_tourner_180' => 'Ruota 180&deg;',
'image_tourner_droite' => 'Ruota 90&deg; a destra',
'image_tourner_gauche' => 'Ruota 90&deg; a sinistra',
'img_indisponible' => 'immagine non disponibile',
'impossible' => 'impossibile',
'info_a_suivre' => 'PANNELLO DI CONTROLLO&nbsp;&raquo;',
'info_a_valider' => '[da convalidare]',
'info_acces_interdit' => 'Accesso vietato',
'info_acces_refuse' => 'Accesso rifiutato',
'info_action' => 'Azione: @action@',
'info_administrer_rubriques' => 'Puoi amministrare questa rubrica e le relative sottorubriche',
'info_adresse_non_indiquee' => 'Non hai indicato l\'indirizzo da testare!',
'info_aide' => 'AIUTO:',
'info_ajouter_mot' => 'Aggiungi questa parola',
'info_annonce' => 'ANNUNCIO',
'info_annonces_generales' => 'Annunci generali:',
'info_article_propose' => 'Articolo proposto',
'info_article_publie' => 'Articolo pubblicato',
'info_article_redaction' => 'Articolo in corso di redazione',
'info_article_refuse' => 'Articolo rifiutato',
'info_article_supprime' => 'Articolo eliminato',
'info_articles' => 'Articoli',
'info_articles_a_valider' => 'Articoli da convalidare',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Articoli proposti',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'autrice(i):',
'info_authentification_ftp' => 'Autenticazione (via FTP).',
'info_bloquer_lien' => 'bloccare questo link',
'info_breves_02' => 'Brevi',
'info_breves_2' => 'brevi',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Brevi da convalidare',
'info_connexion_refusee' => 'Connessione rifiutata',
'info_contact_developpeur' => 'Contatta un programmatore.',
'info_contenance' => 'Questo sito contiene:',
'info_contribution' => 'contributi dei forum',
'info_copyright' => '@spip@ &egrave; un software libero distribuito @lien_gpl@.',
'info_copyright_doc' => 'Per maggiori informazioni, vedi il sito <a href="@spipnet@">http://www.spip.net/it</a>.',
'info_copyright_gpl' => 'sotto licenza GPL',
'info_cours_edition' => 'Articoli in fase di redazione',
'info_creer_repertoire' => 'Creare un file o una cartella chiamata:',
'info_creer_repertoire_2' => 'all\'interno della sottocartella <b>@repertoire@</b>, poi:',
'info_creer_vignette' => 'creazione automatica dell\'anteprima',
'info_deplier' => 'Espandi',
'info_descriptif_nombre' => 'descrizione(i):',
'info_description' => 'Descrizione:',
'info_description_2' => 'Descrizione:',
'info_dimension' => 'Dimensioni:',
'info_document' => 'Documento',
'info_document_indisponible' => 'Questo documento non &egrave; disponibile',
'info_documents' => 'Documenti',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP permette lo scambio di messaggi e la costituzione di forum di discussione
privati tra i membri del sito. Puoi attivare o disattivare questa funzionalit&agrave;.',
'info_ecire_message_prive' => 'Scrivi un messaggio privato',
'info_email_invalide' => 'Indirizzo email non valido.',
'info_en_cours_validation' => 'I tuoi articoli in corso di redazione',
'info_en_ligne' => 'Attualmente on line:',
'info_envoyer_message_prive' => 'Invia un messaggio privato a questa autrice',
'info_erreur_requete' => 'Errore nella richiesta: ',
'info_erreur_squelette2' => 'Nessun modello di layout <b>@fichier@</b> trovato...',
'info_erreur_systeme' => 'Errore di sistema (errno @errsys@)',
'info_erreur_systeme2' => 'Il disco rigido potrebbe essere pieno o la base dati danneggiata. <br />
 <font color=\'red\'>Tenta di <a href=\'@script@\'>ripristinare la base dati</a>,
o contatta il tuo hoster.</font>',
'info_fini' => 'Finito!',
'info_format_image' => 'Formati di file immagine utilizzabili per la creazione delle etichette: @gd_formats@.',
'info_format_non_defini' => 'formato non definito',
'info_grand_ecran' => 'Layout per monitor grandi',
'info_image_aide' => 'AIUTO',
'info_image_process_titre' => 'Metodo per generare thumbnail',
'info_impossible_lire_page' => '<b>Errore!</b> Impossibile  leggere la pagina <tt><html>@test_proxy@</html></tt> attraverso il proxy <tt>',
'info_inclusion_directe' => 'Inclusione diretta:',
'info_inclusion_vignette' => 'Inclusione dell\'immagine:',
'info_installation_systeme_publication' => 'Installazione del sistema di pubblicazione...',
'info_installer_documents' => '&Egrave; possibile installare automaticamente tutti i documenti contenuti nella cartella @upload@.',
'info_installer_ftp' => 'In qualit&agrave; di amministratrice, puoi installare file (via FTP) nella cartella @upload@ per poi selezionarli direttamente.',
'info_installer_images' => '&Egrave; possibile installare delle immagini in formato JPEG, GIF e PNG.',
'info_installer_images_dossier' => 'Installare delle immagini nella cartella @upload@ per poterle selezionare direttamente.',
'info_installer_tous_documents' => 'Installare tutti i documenti',
'info_interface_complete' => 'Interfaccia completa',
'info_interface_simple' => 'Interfaccia semplificata',
'info_joindre_document_article' => 'Puoi allegare a questo articolo dei documenti del tipo',
'info_joindre_document_rubrique' => 'Puoi aggiungere a questa rubrica documenti del tipo',
'info_joindre_documents_article' => 'Puoi allegare all\'articolo documenti del tipo: ',
'info_l_article' => 'l\'articolo',
'info_la_breve' => 'la breve',
'info_la_rubrique' => 'la sezione',
'info_langue_principale' => 'Lingua predefinita del sito',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pixel',
'info_les_auteurs_1' => 'di @les_auteurs@ ',
'info_logo_format_interdit' => 'Solo i logo in formato @formats@ sono permessi.',
'info_logo_max_poids' => 'I logo devono obbligatoriamente avere una dimensione inferiore a @maxi@ (questo file &egrave; di @actuel@).',
'info_logo_max_taille' => 'I logo devono obbligatoriamente avere una dimensione inferiore a @maxi@ (questo file &egrave; di @actuel@).',
'info_mail_fournisseur' => 'tuo@provider.com',
'info_message_2' => 'MESSAGGIO',
'info_message_supprime' => 'MESSAGGIO ELIMINATO',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Data di pubblicazione on line:',
'info_modification_parametres_securite' => 'modifiche dei parametri di sicurezza',
'info_mois_courant' => 'Durante il mese:',
'info_mot_cle_ajoute' => 'La seguente parola chiave &egrave; stata aggiunta a',
'info_multi_herit' => 'Lingua predefinita',
'info_multi_langues_soulignees' => 'Le <u>lingue sottolineate</u> hanno la traduzione di tutti i testi dell\'interfaccia. Se si seleziona una di queste lingue, molti elementi del sito pubblico (date, form) verranno tradotti automaticamente. Per le lingue che non sono sottolineate, invece, tali elementi rimarranno nella lingua principale del sito.',
'info_multilinguisme' => 'Multilinguismo',
'info_nom_non_utilisateurs_connectes' => 'Il tuo nome non appare nella lista delle utenti collegate.',
'info_nom_utilisateurs_connectes' => 'Il tuo nome &egrave; visibile nella lista delle utenti collegate.',
'info_nombre_en_ligne' => 'Attualmente on line:',
'info_non_resultat' => 'Nessun risultato per "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Il sistema di messaggistica interna di questo sito non viene utilizzato.',
'info_nouveau_message' => 'HAI UN NUOVO MESSAGGIO',
'info_nouveaux_messages' => 'HAI @total_messages@ NUOVI MESSAGGI',
'info_numero_abbreviation' => 'N.&nbsp;',
'info_obligatoire' => 'Questa informazione &egrave; obbligatoria',
'info_panne_site_syndique' => 'Il sito in syndication non funziona',
'info_pense_bete' => 'MEMO',
'info_petit_ecran' => 'Layout per monitor piccoli',
'info_petition_close' => 'Petizione chiusa',
'info_pixels' => 'pixels',
'info_plusieurs_mots_trouves' => 'Numerose parole chiave trovate per "@cherche_mot@":',
'info_popularite_5' => 'popolarit&agrave;:',
'info_portfolio' => 'Portfolio',
'info_portfolio_automatique' => 'Portfolio automatico:',
'info_premier_resultat' => '[@debut_limit@ primi risultati su @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ primi risultati su @total@]',
'info_probleme_grave' => 'problema di',
'info_propose_1' => '[@nom_site_spip@] Propone: @titre@',
'info_propose_2' => 'Articolo proposto
---------------',
'info_propose_3' => 'L\'articolo "@titre@" &egrave; proposto per la pubblicazione',
'info_propose_4' => 'Sei invitata a consultare e a dare la tua opinione ',
'info_propose_5' => 'nel forum annesso.

&Egrave; disponibile all\'indirizzo:',
'info_publie_01' => 'L\'articolo "@titre@" &egrave; stato convalidato da @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBBLICA: @titre@',
'info_publie_2' => 'Articolo pubblicato
--------------',
'info_rechercher' => 'Ricerca',
'info_rechercher_02' => 'Cerca:',
'info_remplacer_vignette' => 'Sostituire l\'icona predefinita con una personalizzata:',
'info_retablir_lien' => 'ripristinare questo link',
'info_retirer_mot' => 'Rimuovere questa parola',
'info_retirer_mots' => 'Rimuovere tutte le parole',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'senza titolo',
'info_selectionner_fichier' => 'Puoi selezionare un file della cartella @upload@',
'info_selectionner_fichier_2' => 'Seleziona un file:',
'info_signature_supprimee' => 'Firma eliminata',
'info_signature_supprimee_erreur' => 'Errore: questo codice di eliminazione non corrisponde a nessuna firma',
'info_site_attente' => 'Sito Web in attesa di convalida',
'info_site_reference' => 'Sito repertoriato in linea',
'info_site_refuse' => 'Sito Web rifiutato',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Inserisci un sito in repertorio',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'Cancella l\'immagine',
'info_symbole_bleu' => 'Il simbolo <b>blu</b> indica un <b>memo</b>: cio&egrave; un messaggio ad uso personale.',
'info_symbole_jaune' => 'Il simbolo <b>giallo</b> indica un <b>annuncio a tutte le redattrici</b>: modificabile da tutte le amministratrici e visibile da tutte le redattrici.',
'info_symbole_vert' => 'Il simbolo <b>verde</b> indica i <b>messaggi scambiati con altre utenti  </b> del sito.',
'info_syndication' => 'syndication:',
'info_syndication_articles' => 'articolo/i',
'info_telecharger' => 'Upload dal tuo computer:',
'info_telecharger_nouveau_logo' => 'Upload di un nuovo logo:',
'info_telecharger_ordinateur' => 'Upload dal tuo computer:',
'info_tous_resultats_enregistres' => '[tutti i risultati sono salvati]',
'info_tout_afficher' => 'Visualizza tutto',
'info_travaux_texte' => 'Questo sito non &egrave; stato ancora configurato. Torna pi&ugrave; tardi...',
'info_travaux_titre' => 'Lavori in corso',
'info_trop_resultat' => 'Troppi risultati per "@cherche_mot@" ; restringi la ricerca.',
'info_utilisation_messagerie_interne' => 'Stai utilizzando il sistema di messaggistica interna al sito.',
'info_valider_lien' => 'convalidare questo link',
'info_verifier_image' => ', verifica che le immagini siano state trasferite correttamente.',
'info_vignette_defaut' => 'Loghi predefiniti',
'info_vignette_personnalisee' => 'Loghi personalizzati',
'info_visite' => 'visita:',
'info_visites' => 'visite:',
'info_vos_rendez_vous' => 'I tuoi prossimi appuntamenti',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'I tuoi memo', # MODIF
'item_breve_proposee' => 'Breve proposta',

// L
'lien_afficher_icones_seuls' => 'Mostra solo le icone',
'lien_afficher_texte_icones' => 'Mostra le icone e il testo',
'lien_afficher_texte_seul' => 'Mostra solo il testo',
'lien_liberer' => 'libera',
'lien_liberer_tous' => 'liberare questi articoli',
'lien_nouvea_pense_bete' => 'NUOVO MEMO',
'lien_nouveau_message' => 'NUOVO MESSAGGIO',
'lien_nouvelle_annonce' => 'NUOVO ANNUNCIO',
'lien_petitions' => 'PETIZIONE',
'lien_popularite' => 'popolarit&agrave;: @popularite@%',
'lien_racine_site' => 'ROOT DEL SITO',
'lien_reessayer' => 'Prova di nuovo',
'lien_repondre_message' => 'Rispondi',
'lien_supprimer' => 'cancella',
'lien_tout_afficher' => 'Visualizza tutto ',
'lien_visite_site' => 'visita il sito',
'lien_visites' => '@visites@&nbsp;visite',
'lien_voir_auteur' => 'Vedi questa autrice',
'ligne' => 'Linea',
'login' => 'Collegamento',
'login_acces_prive' => 'accesso all\'area riservata',
'login_autre_identifiant' => 'connettiti con un altro ID',
'login_cookie_accepte' => 'Imposta il tuo browser affinch&eacute; li accetti (almeno per questo sito).',
'login_cookie_oblige' => 'Per identificarsi in modo sicuro su questo sito &egrave; necessario accettare i cookie.',
'login_deconnexion_ok' => 'Disconnessione effettuata.',
'login_erreur_pass' => 'Errore nella password.',
'login_espace_prive' => 'area riservata',
'login_identifiant_inconnu' => 'L\'ID &laquo; @login@ &raquo; risulta inesistente.',
'login_login' => 'Login:',
'login_login2' => 'Login (ID di connessione al sito):',
'login_login_pass_incorrect' => '(Login o password errati.)',
'login_motpasseoublie' => 'password&nbsp;dimenticata?',
'login_non_securise' => 'Attenzione, questo modulo non &egrave; sicuro.
Se non vuoi che la tua password possa essere intercettata sulla rete,
devi attivare Javascript nel tuo browser e',
'login_nouvelle_tentative' => 'Nuovo tentativo',
'login_par_ici' => 'Sei registrata... per di qua...',
'login_pass2' => 'Password:',
'login_preferez_refuser' => '<b>Se preferisci non accettare i cookie</b> c\'&egrave; un altro metodo (meno sicuro) per connettersi:',
'login_recharger' => 'aggiorna questa pagina',
'login_rester_identifie' => 'Conservare l\'identificazione per alcuni giorni',
'login_retour_public' => 'Ritorna al sito pubblico',
'login_retour_site' => 'Ritorna al sito pubblico',
'login_retoursitepublic' => 'ritorna&nbsp;al&nbsp;sito&nbsp;pubblico',
'login_sans_cookiie' => 'Identificazione senza cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'registrati',
'login_test_navigateur' => 'test browser/riconnessione',
'login_verifiez_navigateur' => '(Verifica comunque se il tuo browser ha memorizzato la password...)',

// M
'masquer_colonne' => 'Nascondi questa colonna',
'masquer_trad' => 'nascondere le traduzioni',
'module_fichiers_langues' => 'File lingua',

// N
'navigateur_pas_redirige' => 'Se la pagina non cambia automaticamente, cliccare qui per continuare.',
'numero' => 'Numero',

// O
'occurence' => 'Occorrenza',
'onglet_affacer_base' => 'Svuota il database',
'onglet_auteur' => 'L\'autrice',
'onglet_contenu_site' => 'Contenuto del sito',
'onglet_evolution_visite_mod' => 'Evoluzione',
'onglet_fonctions_avances' => 'Funzioni avanzate',
'onglet_informations_personnelles' => 'Dati personali',
'onglet_interactivite' => 'Interattivit&agrave;',
'onglet_messagerie' => 'Messaggi',
'onglet_messages_internes' => 'Messaggi interni',
'onglet_messages_publics' => 'Messaggi pubblici',
'onglet_messages_vide' => 'Messaggi senza testo',
'onglet_origine_visites' => 'Origine delle visite',
'onglet_repartition_debut' => 'dall\'inizio',
'onglet_repartition_lang' => 'Suddivisione per lingua',
'onglet_repartition_rubrique' => 'Ripartizione per rubriche',
'onglet_save_restaur_base' => 'Salva/ripristina il database',
'onglet_vider_cache' => 'Svuota la cache',
'ortho_trop_de_fautes2' => 'Correggere gli errori pi&ugrave; evidenti e ricontrollare il testo in un secondo tempo.',

// P
'pass_choix_pass' => 'Inserisci una nuova password:',
'pass_erreur' => 'Errore',
'pass_erreur_acces_refuse' => '<b>Errore:</b> non hai pi&ugrave; accesso a questo sito.',
'pass_erreur_code_inconnu' => '<b>Errore:</b> il codice inserito non corriponde a nessuno delle utenti che hanno accesso a questo sito.',
'pass_erreur_non_enregistre' => '<b>Errore:</b> l\'indirizzo <tt>@email_oubli@</tt> non &egrave; registrato su questo sito.',
'pass_erreur_non_valide' => '<b>Errore:</b> questo indirizzo <tt>@email_oubli@</tt> non &egrave; valido!',
'pass_erreur_probleme_technique' => '<b>Errore:</b> l\'email non pu&ograve; essere inviato a causa di un problema tecnico.',
'pass_espace_prive_bla' => 'L\'area riservata di questo sito &egrave; accessibile
unicamente alle utenti registrate.
Una volta iscritta, potrai consultare gli articoli in corso di redazione,
proporre nuovi articoli e partecipare a tutti i forum.',
'pass_forum_bla' => 'Hai chiesto di intervenire su un forum
riservato alle utenti registrate.',
'pass_indiquez_cidessous' => 'Indica qui sotto l\'indirizzo email con il quale ti sei registrata precedentemente.
Riceverai un email con le istruzioni per recuperare i dati di accesso al sito.',
'pass_mail_passcookie' => '(questo &egrave; un messaggio generato automaticamente)
Per recuperare i dati di accesso al sito
@nom_site_spip@ (@adresse_site@)

Clicca su questo link:
    @sendcookie@

Potrai quindi inserire una nuova password 
e riconnetterti all\'area riservata.

',
'pass_mot_oublie' => 'Password dimenticata',
'pass_nouveau_enregistre' => 'La nuova password &egrave; stata salvata.',
'pass_nouveau_pass' => 'Nuova password',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Password dimenticata',
'pass_quitter_fenetre' => 'Chiudi la finestra',
'pass_rappel_login' => 'Ricorda: il tuo ID (login) &egrave; &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Riceverai un email contenente le istruzioni per recuperare i dati di accesso al sito.',
'pass_retour_public' => 'Torna al sito pubblico',
'pass_rien_a_faire_ici' => 'Vicolo cieco...',
'pass_vousinscrire' => 'Registrati al sito',
'precedent' => 'precedente',
'previsualisation' => 'Anteprima',
'previsualiser' => 'Visualizzare l\'anteprima',

// R
'retour' => 'Indietro',

// S
'spip_conforme_dtd' => 'SPIP ritiene che questo documento &egrave; conforme al proprio DOCTYPE:',
'squelette' => 'modello di layout',
'squelette_inclus_ligne' => 'modello incluso, linea',
'squelette_ligne' => 'modello, linea',
'stats_visites_et_popularite' => '@visites@ visite; popolarit&agrave;: @popularite@',
'suivant' => 'successivo',

// T
'taille_ko' => '@taille@&nbsp;Kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => '@taille@&nbsp;byte',
'texte_actualite_site_1' => 'Quando avrai maggiore familiarit&agrave; con l\'interfaccia, clicca su &laquo;',
'texte_actualite_site_2' => 'interfaccia completa',
'texte_actualite_site_3' => '&raquo; per avere accesso a nuove opzioni.',
'texte_creation_automatique_vignette' => 'La creazione automatica di thumbnail di anteprima &egrave; attivata. Se inserisci in questo campo delle immagini in formato @gd_formats@, esse saranno accompagnate da thumbnail con una dimensione massima di @taille_preview@&nbsp;pixel. ',
'texte_documents_associes' => 'I seguenti documenti sono associati all\'articolo,
ma non vi sono stati inseriti direttamente.
A seconda delle impostazioni di pubblicazione del sito,
potranno essere disponibili sotto forma di documenti allegati.',
'texte_erreur_mise_niveau_base' => 'Errore nel database durante l\'aggiornamento.
L\'immagine <b>@fichier@</b> non &egrave; passata (articolo @id_article@).
Prendi nota di questo riferimento, ritenta l\'aggiornamento,
e verifica che le immagini si vedano ancora
negli articoli.',
'texte_erreur_visiteur' => 'Si &egrave; tentato di entrare nell\'area riservata con un login non valido.',
'texte_inc_auth_1' => 'Sei identificata con il
login <b>@auth_login@</b>, ma non esiste pi&ugrave; nel database. 
Prova a ',
'texte_inc_auth_2' => 'collegarti nuovamente',
'texte_inc_auth_3' => ', dopo aver eventualmente effettuato un logout e 
riavviato il tuo browser.',
'texte_inc_config' => 'Le modifiche effettuate in queste pagine influenzano notevolmente il
funzionamento del sito. Non intervenire finch&eacute; non conosci bene i meccanismi del sistema SPIP. <br /><br /><b>In generale, si consiglia di lasciare sempre alla webmistress la configurazione delle opzioni qui presenti.</b>',
'texte_inc_meta_1' => 'La scrittura del file <code>@fichier@</code> ha causato un errore di sistema. L\'amministratrice del sito, ',
'texte_inc_meta_2' => 'verifichi i diritti di scrittura',
'texte_inc_meta_3' => 'nella cartella <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'in corso di redazione',
'texte_statut_poubelle' => 'nel cestino',
'texte_statut_propose_evaluation' => 'proposto per una valutazione',
'texte_statut_publie' => 'pubblicato on line',
'texte_statut_refuse' => 'rifiutato',
'titre_ajouter_mot_cle' => 'AGGIUNGI UNA PAROLA CHIAVE:',
'titre_breve_proposee' => 'Breve proposta',
'titre_breve_publiee' => 'Breve pubblicata',
'titre_breve_refusee' => 'Breve rifiutata',
'titre_cadre_raccourcis' => 'SCELTA RAPIDA:',
'titre_changer_couleur_interface' => 'Cambia il colore dell\'interfaccia',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Puoi amministrare questo articolo',
'titre_image_administrateur' => 'Amministratrice',
'titre_image_aide' => 'Aiuto su questo elemento',
'titre_image_auteur_supprime' => 'Autrice eliminata',
'titre_image_redacteur' => 'Redattrice senza accesso',
'titre_image_redacteur_02' => 'Redattrice',
'titre_image_visiteur' => 'Visitatore',
'titre_joindre_document' => 'ALLEGA UN DOCUMENTO',
'titre_liens_entrants' => 'I link odierni al tuo sito',
'titre_mots_cles' => 'PAROLE CHIAVE',
'titre_probleme_technique' => 'Attenzione: un problema tecnico (server SQL) impedisce l\'accesso a questa parte del sito. Grazie per la comprensione.',
'titre_publier_document' => 'ALLEGA UN DOCUMENTO A QUESTA RUBRICA',
'titre_signatures_attente' => 'Firme in corso di convalida',
'titre_signatures_confirmees' => 'Firme confermate',
'titre_statistiques' => 'Statistiche del sito',
'titre_titre_document' => 'Titolo del documento:',
'todo' => 'prossimo',
'trad_reference' => '(articolo di riferimento)',

// Z
'zbug_balise_b_aval' => ': ciclo B deve precedere ciclo BOUCLE',
'zbug_balise_inexistante' => 'errore @from@: il tag #@balise@ non esiste ', # MODIF
'zbug_balise_sans_argument' => 'Argomento mancante nel tag @balise@',
'zbug_boucle' => 'ciclo',
'zbug_boucle_recursive_undef' => 'ciclo ricorsivo non definito', # MODIF
'zbug_calcul' => 'calcolo',
'zbug_champ_hors_boucle' => 'Campo @champ@ fuori dal ciclo',
'zbug_champ_hors_motif' => 'Campo @champ@ fuori da un ciclo di motivo @motif@', # MODIF
'zbug_code' => 'codice',
'zbug_critere_inconnu' => 'criterio sconosciuto @critere@', # MODIF
'zbug_distant_interdit' => 'esterno non accessibile', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'doppioni su una tabella senza chiave primaria atomica', # MODIF
'zbug_doublon_table_sans_index' => 'doppioni su una tabella senza indice', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: doppia definizione', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: chiusura tag mancante', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Sintassi del ciclo errata', # MODIF
'zbug_erreur_compilation' => 'Errore di compilazione',
'zbug_erreur_execution_page' => 'errore di esecuzione della pagina', # MODIF
'zbug_erreur_filtre' => 'Errore: filtro <b>&laquo; @filtre@ &raquo;</b> non esistente', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} si applica unicamente ai cicli (FORUMS) o (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Errore/i nel modello di layout',
'zbug_hors_compilation' => 'Fuori Compilazione',
'zbug_info_erreur_squelette' => 'Errore sul sito',
'zbug_inversion_ordre_inexistant' => 'inversione di un ordine non esistente', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION senza criterio {pagination} oppure usato in un ciclo ricorsivo', # MODIF
'zbug_parametres_inclus_incorrects' => 'Parametri di inclusione non corretti', # MODIF
'zbug_profile' => 'Tempo di elaborazione: @time@',
'zbug_resultat' => 'risultato',
'zbug_serveur_indefini' => 'server SQL non definito', # MODIF
'zbug_statistiques' => 'Statistiche delle query SQL in ordine di durata',
'zbug_table_inconnue' => 'Tabella SQL &laquo; @table@ &raquo; sconosciuta',
'zxml_connus_attributs' => 'attributi conosciuti',
'zxml_de' => 'di',
'zxml_inconnu_attribut' => 'attributo sconosciuto',
'zxml_inconnu_balise' => 'segnaposto sconosciuto',
'zxml_inconnu_entite' => 'entit&agrave; sconosciuta',
'zxml_inconnu_id' => 'ID sconosciuto',
'zxml_mais_de' => 'ma di',
'zxml_non_conforme' => 'non &egrave; conforme al motivo',
'zxml_non_fils' => 'non &egrave; un figlio di',
'zxml_nonvide_balise' => 'segnaposto non vuoto',
'zxml_obligatoire_attribut' => 'attributo obbligatorio ma assente in',
'zxml_succession_fils_incorrecte' => 'successione dei figli non corretta',
'zxml_survoler' => 'passarci sopra col mouse per vedere i corretti',
'zxml_valeur_attribut' => 'valore dell\'attributo',
'zxml_vide_balise' => 'tag vuoto',
'zxml_vu' => 'visto in precedenza'
);

?>
